@@ -29,7 +29,10 @@ from magnum.api.controllers.v1 import baymodel
 from magnum.api.controllers.v1 import certificate
 from magnum.api.controllers.v1 import cluster
 from magnum.api.controllers.v1 import cluster_template
+from magnum.api.controllers.v1 import federation
 from magnum.api.controllers.v1 import magnum_services
+from magnum.api.controllers.v1 import quota
+from magnum.api.controllers.v1 import stats
 from magnum.api.controllers import versions as ver
 from magnum.api import expose
 from magnum.api import http_error
@@ -85,12 +88,24 @@ class V1(controllers_base.APIBase):
     clusters = [link.Link]
     """Links to the clusters resource"""
 
+    quotas = [link.Link]
+    """Links to the quotas resource"""
+
     certificates = [link.Link]
     """Links to the certificates resource"""
 
     mservices = [link.Link]
     """Links to the magnum-services resource"""
 
+    stats = [link.Link]
+    """Links to the stats resource"""
+
+    # Links to the federations resources
+    federations = [link.Link]
+
+    nodegroups = [link.Link]
+    """Links to the nodegroups resource"""
+
     @staticmethod
     def convert():
         v1 = V1()
@@ -129,6 +144,12 @@ class V1(controllers_base.APIBase):
                                            pecan.request.host_url,
                                            'clusters', '',
                                            bookmark=True)]
+        v1.quotas = [link.Link.make_link('self', pecan.request.host_url,
+                                         'quotas', ''),
+                     link.Link.make_link('bookmark',
+                                         pecan.request.host_url,
+                                         'quotas', '',
+                                         bookmark=True)]
         v1.certificates = [link.Link.make_link('self', pecan.request.host_url,
                                                'certificates', ''),
                            link.Link.make_link('bookmark',
@@ -141,6 +162,27 @@ class V1(controllers_base.APIBase):
                                             pecan.request.host_url,
                                             'mservices', '',
                                             bookmark=True)]
+        v1.stats = [link.Link.make_link('self', pecan.request.host_url,
+                                        'stats', ''),
+                    link.Link.make_link('bookmark',
+                                        pecan.request.host_url,
+                                        'stats', '',
+                                        bookmark=True)]
+        v1.federations = [link.Link.make_link('self', pecan.request.host_url,
+                                              'federations', ''),
+                          link.Link.make_link('bookmark',
+                                              pecan.request.host_url,
+                                              'federations', '',
+                                              bookmark=True)]
+        v1.nodegroups = [link.Link.make_link('self', pecan.request.host_url,
+                                             'clusters/{cluster_id}',
+                                             'nodegroups'),
+                         link.Link.make_link('bookmark',
+                                             pecan.request.host_url,
+                                             'clusters/{cluster_id}',
+                                             'nodegroups',
+                                             bookmark=True)]
+
         return v1
 
 
@@ -151,8 +193,11 @@ class Controller(controllers_base.Controller):
     baymodels = baymodel.BayModelsController()
     clusters = cluster.ClustersController()
     clustertemplates = cluster_template.ClusterTemplatesController()
+    quotas = quota.QuotaController()
     certificates = certificate.CertificateController()
     mservices = magnum_services.MagnumServiceController()
+    stats = stats.StatsController()
+    federations = federation.FederationsController()
 
     @expose.expose(V1)
     def get(self):
