@@ -22,10 +22,15 @@ Create Date: 2015-04-25 02:17:51.486547
 revision = '4956f03cabad'
 down_revision = '2d8657c0cdc'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 
 def upgrade():
     op.add_column('baymodel', sa.Column('cluster_distro',
-                  sa.String(length=255), nullable=True))
+                  String(255, mysql_ndb_type=TINYTEXT), nullable=True))
