@@ -25,8 +25,13 @@ Create Date: 2016-02-17 14:16:12.927874
 revision = '5d4caa6e0a42'
 down_revision = 'bb42b7cad130'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from oslo_db.sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
+
+from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
 
 
 def upgrade():
@@ -34,8 +39,10 @@ def upgrade():
                     new_column_name='trust_id',
                     existing_type=sa.String(255))
     op.add_column('bay', sa.Column('trustee_username',
-                  sa.String(length=255), nullable=True))
+                  String(255, mysql_ndb_type=TINYTEXT),
+                  nullable=True))
     op.add_column('bay', sa.Column('trustee_user_id',
                   sa.String(length=255), nullable=True))
     op.add_column('bay', sa.Column('trustee_password',
-                  sa.String(length=255), nullable=True))
+                  String(255, mysql_ndb_type=TINYTEXT),
+                  nullable=True))
