@@ -48,7 +48,9 @@ _FACADE = None
 def _create_facade_lazily():
     global _FACADE
     if _FACADE is None:
-        _FACADE = db_session.EngineFacade.from_config(CONF)
+        # FIXME(karolinku): autocommit=True it's not compatible with
+        # SQLAlchemy 2.0, and will be removed in future
+        _FACADE = db_session.EngineFacade.from_config(CONF, autocommit=True)
         if profiler_sqlalchemy:
             if CONF.profiler.enabled and CONF.profiler.trace_sqlalchemy:
                 profiler_sqlalchemy.add_tracing(sa, _FACADE.get_engine(), "db")
@@ -286,7 +288,7 @@ class Connection(api.Connection):
             query = model_query(models.Cluster, session=session)
             query = add_identity_filter(query, cluster_id)
             try:
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 raise exception.ClusterNotFound(cluster=cluster_id)
 
@@ -344,7 +346,7 @@ class Connection(api.Connection):
         query = self._add_tenant_filters(context, query)
         public_q = model_query(models.ClusterTemplate).filter_by(public=True)
         query = query.union(public_q)
-        query = query.filter_by(id=cluster_template_id)
+        query = query.filter(models.ClusterTemplate.id == cluster_template_id)
         try:
             return query.one()
         except NoResultFound:
@@ -356,7 +358,8 @@ class Connection(api.Connection):
         query = self._add_tenant_filters(context, query)
         public_q = model_query(models.ClusterTemplate).filter_by(public=True)
         query = query.union(public_q)
-        query = query.filter_by(uuid=cluster_template_uuid)
+        query = query.filter(
+                models.ClusterTemplate.uuid == cluster_template_uuid)
         try:
             return query.one()
         except NoResultFound:
@@ -368,7 +371,8 @@ class Connection(api.Connection):
         query = self._add_tenant_filters(context, query)
         public_q = model_query(models.ClusterTemplate).filter_by(public=True)
         query = query.union(public_q)
-        query = query.filter_by(name=cluster_template_name)
+        query = query.filter(
+                models.ClusterTemplate.name == cluster_template_name)
         try:
             return query.one()
         except MultipleResultsFound:
@@ -389,7 +393,8 @@ class Connection(api.Connection):
     def _is_publishing_cluster_template(self, values):
         if (len(values) == 1 and (
                 ('public' in values and values['public'] is True) or
-                ('hidden' in values))):
+                ('hidden' in values) or
+                ('tags' in values and values['tags'] is not None))):
             return True
         return False
 
@@ -426,7 +431,7 @@ class Connection(api.Connection):
             query = model_query(models.ClusterTemplate, session=session)
             query = add_identity_filter(query, cluster_template_id)
             try:
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 raise exception.ClusterTemplateNotFound(
                     clustertemplate=cluster_template_id)
@@ -496,7 +501,7 @@ class Connection(api.Connection):
             query = model_query(models.X509KeyPair, session=session)
             query = add_identity_filter(query, x509keypair_id)
             try:
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 raise exception.X509KeyPairNotFound(x509keypair=x509keypair_id)
 
@@ -538,7 +543,7 @@ class Connection(api.Connection):
             query = model_query(models.MagnumService, session=session)
             query = add_identity_filter(query, magnum_service_id)
             try:
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 raise exception.MagnumServiceNotFound(
                     magnum_service_id=magnum_service_id)
@@ -622,7 +627,7 @@ class Connection(api.Connection):
             try:
                 query = query.filter_by(project_id=project_id).filter_by(
                     resource=resource)
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 msg = (_('project_id %(project_id)s resource %(resource)s.') %
                        {'project_id': project_id, 'resource': resource})
@@ -634,11 +639,12 @@ class Connection(api.Connection):
     def delete_quota(self, project_id, resource):
         session = get_session()
         with session.begin():
-            query = model_query(models.Quota, session=session)
+            query = model_query(models.Quota, session=session) \
+                .filter_by(project_id=project_id) \
+                .filter_by(resource=resource)
 
             try:
-                query.filter_by(project_id=project_id).filter_by(
-                    resource=resource).one()
+                query.one()
             except NoResultFound:
                 msg = (_('project_id %(project_id)s resource %(resource)s.') %
                        {'project_id': project_id, 'resource': resource})
@@ -774,7 +780,7 @@ class Connection(api.Connection):
             query = model_query(models.Federation, session=session)
             query = add_identity_filter(query, federation_id)
             try:
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 raise exception.FederationNotFound(federation=federation_id)
 
@@ -836,7 +842,7 @@ class Connection(api.Connection):
             query = add_identity_filter(query, nodegroup_id)
             query = query.filter_by(cluster_id=cluster_id)
             try:
-                ref = query.with_lockmode('update').one()
+                ref = query.with_for_update().one()
             except NoResultFound:
                 raise exception.NodeGroupNotFound(nodegroup=nodegroup_id)
 
