@@ -52,6 +52,7 @@ PASSWORD="$PASSWORD"
 CLUSTER_NETWORK="$CLUSTER_NETWORK"
 CLUSTER_NETWORK_NAME="$CLUSTER_NETWORK_NAME"
 CLUSTER_SUBNET="$CLUSTER_SUBNET"
+CLUSTER_SUBNET_CIDR="$CLUSTER_SUBNET_CIDR"
 TLS_DISABLED="$TLS_DISABLED"
 KUBE_DASHBOARD_ENABLED="$KUBE_DASHBOARD_ENABLED"
 INFLUX_GRAFANA_DASHBOARD_ENABLED="$INFLUX_GRAFANA_DASHBOARD_ENABLED"
@@ -59,6 +60,13 @@ VERIFY_CA="$VERIFY_CA"
 CLUSTER_UUID="$CLUSTER_UUID"
 MAGNUM_URL="$MAGNUM_URL"
 MONITORING_ENABLED="$MONITORING_ENABLED"
+MONITORING_RETENTION_DAYS="$MONITORING_RETENTION_DAYS"
+MONITORING_RETENTION_SIZE="$MONITORING_RETENTION_SIZE"
+MONITORING_INTERVAL_SECONDS="$MONITORING_INTERVAL_SECONDS"
+MONITORING_STORAGE_CLASS_NAME="$MONITORING_STORAGE_CLASS_NAME"
+MONITORING_INGRESS_ENABLED="$MONITORING_INGRESS_ENABLED"
+CLUSTER_BASIC_AUTH_SECRET="$CLUSTER_BASIC_AUTH_SECRET"
+CLUSTER_ROOT_DOMAIN_NAME="$CLUSTER_ROOT_DOMAIN_NAME"
 PROMETHEUS_OPERATOR_CHART_TAG="$PROMETHEUS_OPERATOR_CHART_TAG"
 PROMETHEUS_ADAPTER_ENABLED="$PROMETHEUS_ADAPTER_ENABLED"
 PROMETHEUS_ADAPTER_CHART_TAG="$PROMETHEUS_ADAPTER_CHART_TAG"
@@ -68,6 +76,7 @@ REGION_NAME="$REGION_NAME"
 HTTP_PROXY="$HTTP_PROXY"
 HTTPS_PROXY="$HTTPS_PROXY"
 NO_PROXY="$NO_PROXY"
+HYPERKUBE_PREFIX="$HYPERKUBE_PREFIX"
 KUBE_TAG="$KUBE_TAG"
 CLOUD_PROVIDER_TAG="$CLOUD_PROVIDER_TAG"
 CLOUD_PROVIDER_ENABLED="$CLOUD_PROVIDER_ENABLED"
@@ -103,6 +112,9 @@ KUBEAPI_OPTIONS="$KUBEAPI_OPTIONS"
 KUBEPROXY_OPTIONS="$KUBEPROXY_OPTIONS"
 KUBESCHEDULER_OPTIONS="$KUBESCHEDULER_OPTIONS"
 OCTAVIA_ENABLED="$OCTAVIA_ENABLED"
+OCTAVIA_PROVIDER="$OCTAVIA_PROVIDER"
+OCTAVIA_LB_ALGORITHM="$OCTAVIA_LB_ALGORITHM"
+OCTAVIA_LB_HEALTHCHECK="$OCTAVIA_LB_HEALTHCHECK"
 KUBE_SERVICE_ACCOUNT_KEY="$KUBE_SERVICE_ACCOUNT_KEY"
 KUBE_SERVICE_ACCOUNT_PRIVATE_KEY="$KUBE_SERVICE_ACCOUNT_PRIVATE_KEY"
 PROMETHEUS_TAG="$PROMETHEUS_TAG"
@@ -147,6 +159,7 @@ CONTAINERD_TARBALL_URL="$CONTAINERD_TARBALL_URL"
 CONTAINERD_TARBALL_SHA256="$CONTAINERD_TARBALL_SHA256"
 POST_INSTALL_MANIFEST_URL="$POST_INSTALL_MANIFEST_URL"
 METRICS_SCRAPER_TAG="$METRICS_SCRAPER_TAG"
+CLUSTER_SUBNET_CIDR="$CLUSTER_SUBNET_CIDR"
 EOF
 }
 
