@@ -13,5 +13,5 @@
 #    limitations under the License.
 
 version = '1.0.0'
-driver = 'swarm_atomic'
-container_version = '1.9.1'
+driver = 'swarm_fedora_atomic_v1'
+container_version = '1.12.6'
