@@ -15,9 +15,9 @@
 
 import copy
 import os
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
@@ -26,9 +26,11 @@ import pecan
 import testscenarios
 
 from magnum.common import context as magnum_context
+from magnum.common import keystone as magnum_keystone
 from magnum.objects import base as objects_base
 from magnum.tests import conf_fixture
 from magnum.tests import fake_notifier
+from magnum.tests import output_fixture
 from magnum.tests import policy_fixture
 
 
@@ -63,13 +65,23 @@ class TestCase(base.BaseTestCase):
                 }
             }
         }
+
+        trustee_domain_id = '12345678-9012-3456-7890-123456789abc'
+
         self.context = magnum_context.RequestContext(
             auth_token_info=token_info,
             project_id='fake_project',
-            user_id='fake_user')
+            user_id='fake_user',
+            is_admin=False)
+
+        self.global_mocks = {}
+
+        self.keystone_client = magnum_keystone.KeystoneClientV3(self.context)
 
         self.policy = self.useFixture(policy_fixture.PolicyFixture())
 
+        self.output = self.useFixture(output_fixture.OutputStreamCapture())
+
         self.useFixture(fixtures.MockPatchObject(
             oslo_messaging, 'Notifier',
             fake_notifier.FakeNotifier))
@@ -83,15 +95,30 @@ class TestCase(base.BaseTestCase):
                 kwargs['project_id'] = 'fake_project'
             if not kwargs.get('user_id'):
                 kwargs['user_id'] = 'fake_user'
+            if not kwargs.get('is_admin'):
+                kwargs['is_admin'] = False
 
             context = magnum_context.RequestContext(*args, **kwargs)
             return magnum_context.RequestContext.from_dict(context.to_dict())
 
         p = mock.patch.object(magnum_context, 'make_context',
                               side_effect=make_context)
+
+        self.global_mocks['magnum.common.context.make_context'] = p
+
+        q = mock.patch.object(magnum_keystone.KeystoneClientV3,
+                              'trustee_domain_id',
+                              return_value=trustee_domain_id)
+
+        self.global_mocks[
+            'magnum.common.keystone.KeystoneClientV3.trustee_domain_id'] = q
+
         self.mock_make_context = p.start()
         self.addCleanup(p.stop)
 
+        self.mock_make_trustee_domain_id = q.start()
+        self.addCleanup(q.stop)
+
         self.useFixture(conf_fixture.ConfFixture())
         self.useFixture(fixtures.NestedTempfile())
 
@@ -104,6 +131,12 @@ class TestCase(base.BaseTestCase):
 
         self.addCleanup(reset_pecan)
 
+    def start_global(self, name):
+        self.global_mocks[name].start()
+
+    def stop_global(self, name):
+        self.global_mocks[name].stop()
+
     def _restore_obj_registry(self):
         objects_base.MagnumObjectRegistry._registry._obj_classes \
             = self._base_test_obj_backup
