@@ -41,7 +41,7 @@ class TestRootController(api_base.FunctionalTest):
                                [{u'href': u'http://localhost/v1/',
                                  u'rel': u'self'}],
                            u'status': u'CURRENT',
-                           u'max_version': u'1.9',
+                           u'max_version': u'1.10',
                            u'min_version': u'1.1'}]}
 
         self.v1_expected = {
@@ -195,7 +195,7 @@ class TestHeathcheck(api_base.FunctionalTest):
         # Read current file and create new one
         config = ConfigParser.RawConfigParser()
         config.read(self.get_path(paste_ini))
-        config.set('filter:healthcheck',
+        config.set('app:healthcheck',
                    'disable_by_file_path',
                    self.tempdir + "/disable")
         with open(self.tempdir + "/paste.ini", 'wt') as configfile:
